@@ -5,7 +5,7 @@ __author__ = "Philipp Niedermayer"
 __contact__ = "eltos@outlook.de"
 
 
-__version__ = "0.1.6"
+__version__ = "0.1.7"
 
 
 from .colors import *
@@ -16,5 +16,12 @@ from .phasespace import *
 
 from . import hooks
 
-hooks.register_matplotlib_options()
-hooks.register_pint_options()
+try:
+    hooks.register_matplotlib_options()
+except:
+    pass
+
+try:
+    hooks.register_pint_options()
+except:
+    pass
