@@ -384,14 +384,53 @@ class PhaseSpacePlot(XsuitePlot):
         }
         return titles.get(f"{a}-{b}", titles.get(f"{b}-{a}", f"{a}-{b} phase space"))
 
+    def axline(self, kind, val, also_on_normalized=True, subplots="all", **kwargs):
+        """Plot a vertical or horizontal line for a given coordinate
+
+        Args:
+            kind (str): Phase space coordinate
+            val (float): Value of phase space coordinate
+            also_on_normalized (bool, optional): If true, also plot line for related (de-)normalized phase space coordinate
+            subplots (list of int): Subplots to plot line onto. Defaults to all with matching coordinates.
+            kwargs: Arguments for axvline or axhline
+
+        """
+
+        kwargs = style(kwargs, c="k")
+
+        for i, (ab, ax) in enumerate(zip(self.kind, self.axflat)):
+            if subplots is not "all" and i not in subplots:
+                continue
+
+            for a, line in zip(ab, (ax.axvline, ax.axhline)):
+                if a == kind:
+                    # same axis found, draw line
+                    line(val * self.factor_for(kind), **kwargs)
+
+                elif self.twiss is not None and kind.lower() == a.lower():
+                    # related (de-)normalized axis found, transform and draw line
+                    xy = kind.lower()[-1]
+                    if kind in "x,y":  # x,y -> X,Y
+                        v = normalized_coordinates(val, 0, self.twiss, xy)[0]
+                    elif kind in "X,Y":  # X,Y -> x,y
+                        v = denormalized_coordinates(val, 0, self.twiss, xy)[0]
+                    elif kind in "px,py":  # px,py -> Px,Py
+                        v = normalized_coordinates(0, val, self.twiss, xy)[1]
+                    elif kind in "Px,Py":  # Px,Py -> px,py
+                        v = denormalized_coordinates(0, val, self.twiss, xy)[1]
+                    else:
+                        continue
+                    line(v * self.factor_for(a), **kwargs)
+
     def plot_hamiltonian_kobayashi(
         self,
-        i,
+        subplot,
         S,
         mu,
         *,
         q=None,
         extend=1,
+        autoscale=True,
         separatrix=True,
         separatrix_kwargs=None,
         equipotentials=True,
@@ -400,11 +439,12 @@ class PhaseSpacePlot(XsuitePlot):
         """Plot separatrix and equipotential lines of kobayashi hamiltonian
 
         Args:
-            i (int): Index of subplot
+            subplot (int): Index of subplot
             S (float): Virtual sextupole strength in m^(-1/2)
             mu (float): Virtual sextupole phase in rad/2pi
             q (float, optional): Tune. Defaults to tune from twiss.
             extend (float, optional): Extend of separatrix and equipotential lines. If > 1 they are drawn beyond the the stable region.
+            autoscale (bool, optional): Whether to autoscale axis or not
             separatrix (bool, optional): Plot separatrix. Defaults to True.
             separatrix_kwargs (dict, optional): Keyword arguments for separatrix line plot.
             equipotentials (bool, optional): Plot equipotential lines. Defaults to True.
@@ -413,8 +453,8 @@ class PhaseSpacePlot(XsuitePlot):
 
         # TODO: provide option to plot for different particle delta (dispersion shifts and chromaticity shrinks the triangle)
 
-        ax = self.axflat[i]
-        a, b = self.kind[i]
+        ax = self.axflat[subplot]
+        a, b = self.kind[subplot]
         config = {
             "x-px": ("x", False),
             "y-py": ("y", False),
@@ -459,11 +499,13 @@ class PhaseSpacePlot(XsuitePlot):
             XY[1] *= self.factor_for(b)
             return XY
 
-        # plot separatrix
-        if separatrix:
-            kwarg = style(separatrix_kwargs, color="r", ls="--", label="Separatrix")
+        lim = ax.dataLim
+        with FixedLimits(ax):
+
+            # plot separatrix
+            if separatrix:
+                kwarg = style(separatrix_kwargs, color="r", ls="--", label="Separatrix")
 
-            with FixedLimits(ax):
                 t = extend
                 for X, Y in (
                     [(-2, -2), (-2 * t, 2 * t)],
@@ -474,20 +516,30 @@ class PhaseSpacePlot(XsuitePlot):
                     Y = h * 3**0.5 * np.array(Y) / 2
                     ax.plot(*transform((X, Y)), **kwarg)
 
-        # plot equipotential lines
-        if equipotentials:
-            kwargs = style(
-                equipotentials_kwargs, colors="lightgray", linewidths=1, alpha=0.5
-            )
+            # plot equipotential lines
+            if equipotentials:
+                kwargs = style(
+                    equipotentials_kwargs, colors="lightgray", linewidths=1, alpha=0.5
+                )
 
-            # X = h * np.linspace(-5, 5, 500)
-            X = extend * h * np.linspace(-1, 2, 500)
-            Y = extend * h * 3**0.5 * np.linspace(-1, 1, 500)
-            X, Y = np.meshgrid(X, Y)
-            H = (3 * h * (X**2 + Y**2) + 3 * X * Y**2 - X**3) / h**3 / 4
-            levels = np.linspace(0, extend, int(10 * extend)) ** 2
+                # X = h * np.linspace(-5, 5, 500)
+                X = extend * h * np.linspace(-1, 2, 500)
+                Y = extend * h * 3**0.5 * np.linspace(-1, 1, 500)
+                X, Y = np.meshgrid(X, Y)
+                H = (3 * h * (X**2 + Y**2) + 3 * X * Y**2 - X**3) / h**3 / 4
+                levels = np.linspace(0, extend, int(10 * extend)) ** 2
 
-            with FixedLimits(ax):
                 ax.contour(*transform((X, Y)), H, levels=levels, **kwargs)
 
-            ax.grid(False)
+                ax.grid(False)
+
+        # autoscale to separatrix
+        if autoscale:
+            edges = np.array(
+                [(2 * h, -h, -h, 2 * h), (0, -(3**0.5) * h, 3**0.5 * h, 0)]
+            )
+            x, y = transform(edges)
+            ax.dataLim = lim.union(
+                [mpl.transforms.Bbox([[min(x), min(y)], [max(x), max(y)]])]
+            )
+            ax.autoscale()
